@@ -23,6 +23,7 @@ import (
 	"sync"
 	"time"
 
+	"github.com/google/shlex"
 	"github.com/jessevdk/go-flags"
 	jsoniter "github.com/json-iterator/go"
 	"github.com/mattn/go-shellwords"
@@ -297,6 +298,10 @@ func (v *vgrep) grep(args []string) {
 		}
 		cmd = append(cmd, args...)
 		greptype = RIPGrep
+		config := os.Getenv("RIPGREP_CONFIG_PATH")
+		if len(config) != 0 {
+			env = "RIPGREP_CONFIG_PATH=" + config
+		}
 	} else if v.insideGitTree() && !v.NoGit {
 		env = "HOME="
 		cmd = []string{
@@ -383,10 +388,13 @@ func (v *vgrep) splitMatch(match string, greptype string) (file, line, content s
 }
 
 // getEditor returns the EDITOR environment variable (default="vim").
-func (v *vgrep) getEditor() string {
-	editor := os.Getenv("EDITOR")
+func (v *vgrep) getEditor() []string {
+	editor, err := shlex.Split(os.Getenv("EDITOR"))
 	if len(editor) == 0 {
-		editor = "vim"
+		editor = []string{"vim"}
+	}
+	if err != nil {
+		logrus.Info("Error parsing EDITOR, falling back to `vim'")
 	}
 	return editor
 }
@@ -400,6 +408,16 @@ func (v *vgrep) getEditorLineFlag() string {
 	return editor
 }
 
+// getEditorLineFlagReversed returns the EDITORLINEFLAGREVERSED
+// environment variable (default=false).
+func (v *vgrep) getEditorLineFlagReversed() bool {
+	order, err := strconv.ParseBool(os.Getenv("EDITORLINEFLAGREVERSED"))
+	if err != nil {
+		order = false
+	}
+	return order
+}
+
 // Create the lock file to guard against concurrent processes
 func (v *vgrep) makeLockFile() error {
 
@@ -984,10 +1002,10 @@ func (v *vgrep) commandDelete(indices []int) bool {
 
 	for offset, idx := range indices {
 		logrus.Debugf("deleting index %d", idx)
-		for i := idx + 1; i < len(v.matches); i++ {
+		index := idx - offset
+		for i := index; i < len(v.matches); i++ {
 			v.matches[i][0] = strconv.Itoa(i - 1)
 		}
-		index := idx - offset
 		v.matches = append(v.matches[:index], v.matches[index+1:]...)
 	}
 
@@ -1064,21 +1082,28 @@ func (v *vgrep) commandShow(index int) bool {
 		return false
 	}
 
+	lFlag_reversed := v.getEditorLineFlagReversed()
+	if !lFlag_reversed {
+		_, file := filepath.Split(editor[0])
+		switch file {
+		case "emacs", "emacsclient", "nano":
+			lFlag_reversed = true
+		default:
+			// leave flag unchanged if already set
+		}
+	}
+
 	lFlag := fmt.Sprintf("%s%d", v.getEditorLineFlag(), line)
 
 	logrus.Debugf("opening index %d via: %s %s %s", index, editor, path, lFlag)
 
 	var cmd *exec.Cmd
-	_, file := filepath.Split(editor)
-	switch file {
-	case "emacs", "emacsclient":
-		// emacs expects the line before the file
-		cmd = exec.Command(editor, lFlag, path)
-	default:
-		// default to adding the line after the file
-		cmd = exec.Command(editor, path, lFlag)
+	if lFlag_reversed {
+		editor = append(editor, lFlag, path)
+	} else {
+		editor = append(editor, path, lFlag)
 	}
-
+	cmd = exec.Command(editor[0], editor[1:]...)
 	cmd.Stdin = os.Stdin
 	cmd.Stdout = os.Stdout
 	cmd.Stderr = os.Stderr
